function cookiesManager (expireDays = 365, cookiesPrefix = '') {

    if (typeof expireDays !== 'number')
        return console.error('Cookie Manager - Invalid argument : expireDays is not a number.');


    if (typeof cookiesPrefix !== 'string')
        return console.error('Cookie Manager - Invalid argument : cookiesPrefix is not a string.');


    if (!$('#cookieModal') || !$('#cookieAlert'))
        return;


    $('#cookieAlert').outerHeight();


    // Show the alert if accept_cookie not existing
    if (!getCookie(cookiesPrefix + "cookie_accept"))
        $('#cookieAlert').addClass('show');


    // Check & set the toggles input
    $("input[data-cookie-name]").each(function () {

        if (getCookie(cookiesPrefix + $(this).data('cookie-name')) === 'false')
            $(this).bootstrapToggle('off');
    });


    // Set all the cookies value to true when clicking on the "I Accept" button
    $('#cookieAcceptAll').click(function () {

        setCookie(cookiesPrefix + "cookie_accept", true, expireDays);

        $("input[data-cookie-name]").each(function () {
            setCookie(cookiesPrefix + $(this).data('cookie-name'), true, expireDays);
        });

        $('#cookieAlert').removeClass("show");
    });


    // Set the cookies with the toggle value when clicking on the "Save & Exit" button, true if checked, false when not
    $('#cookieSave').click(function () {
        setCookie(cookiesPrefix + "cookie_accept", true, expireDays);

        $("input[data-cookie-name]").each(function () {
            setCookie(cookiesPrefix + $(this).data('cookie-name'), $(this).prop('checked'), expireDays);
        });

    });


    // Close #cookieAlert when #cookieModal is openned
    $('#cookieModal').on('shown.bs.modal', function (e) {
        $('#cookieAlert').removeClass("show");
    })


    // Cookie functions from w3schools
    function setCookie(cname, cvalue, exdays) {
        var d = new Date();
        d.setTime(d.getTime() + (exdays * 24 * 60 * 60 * 1000));
        var expires = "expires=" + d.toUTCString();
        document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";
    }

    function getCookie(cname) {
        var name = cname + "=";
        var ca = document.cookie.split(';');
        for (var i = 0; i < ca.length; i++) {
            var c = ca[i];
            while (c.charAt(0) == ' ') {
                c = c.substring(1);
            }
            if (c.indexOf(name) == 0) {
                return c.substring(name.length, c.length);
            }
        }
        return "";
    }
}